@@ -35,7 +35,7 @@ use Coro::Event;
 
 use base Exporter::;
 
-our $VERSION = 1.9;
+our $VERSION = 2.0;
 our @EXPORT_OK = "select";
 
 sub import {
@@ -49,11 +49,11 @@ sub import {
 
 sub select(;*$$$) { # not the correct prototype, but well... :()
    if (@_ == 0) {
-      return CORE::select;
+      return CORE::select
    } elsif (@_ == 1) {
-      return CORE::select $_[0];
+      return CORE::select $_[0]
    } elsif (defined $_[3] && !$_[3]) {
-      return CORE::select (@_);
+      return CORE::select $_[0], $_[1], $_[2], $_[3]
    } else {
       my $current = $Coro::current;
       my $nfound = 0;
@@ -85,7 +85,7 @@ sub select(;*$$$) { # not the correct prototype, but well... :()
       # wait here
 
       $_->cancel for @w;
-      return $nfound;
+      return $nfound
    }
 }
 
